summaryrefslogtreecommitdiff
path: root/chromium/ipc/ipc_channel_reader.h
diff options
context:
space:
mode:
authorAndras Becsi <andras.becsi@digia.com>2014-03-18 13:16:26 +0100
committerFrederik Gladhorn <frederik.gladhorn@digia.com>2014-03-20 15:55:39 +0100
commit3f0f86b0caed75241fa71c95a5d73bc0164348c5 (patch)
tree92b9fb00f2e9e90b0be2262093876d4f43b6cd13 /chromium/ipc/ipc_channel_reader.h
parente90d7c4b152c56919d963987e2503f9909a666d2 (diff)
downloadqtwebengine-chromium-3f0f86b0caed75241fa71c95a5d73bc0164348c5.tar.gz
Update to new stable branch 1750
This also includes an updated ninja and chromium dependencies needed on Windows. Change-Id: Icd597d80ed3fa4425933c9f1334c3c2e31291c42 Reviewed-by: Zoltan Arvai <zarvai@inf.u-szeged.hu> Reviewed-by: Zeno Albisser <zeno.albisser@digia.com>
Diffstat (limited to 'chromium/ipc/ipc_channel_reader.h')
-rw-r--r--chromium/ipc/ipc_channel_reader.h12
1 files changed, 8 insertions, 4 deletions
diff --git a/chromium/ipc/ipc_channel_reader.h b/chromium/ipc/ipc_channel_reader.h
index 9c398bdce35..130384659fc 100644
--- a/chromium/ipc/ipc_channel_reader.h
+++ b/chromium/ipc/ipc_channel_reader.h
@@ -42,8 +42,12 @@ class ChannelReader {
// data. See ReadData for more.
bool AsyncReadComplete(int bytes_read);
- // Returns true if the given message is the "hello" message sent on channel
- // set-up.
+ // Returns true if the given message is internal to the IPC implementation,
+ // like the "hello" message sent on channel set-up.
+ bool IsInternalMessage(const Message& m) const;
+
+ // Returns true if the given message is an Hello message
+ // sent on channel set-up.
bool IsHelloMessage(const Message& m) const;
protected:
@@ -76,8 +80,8 @@ class ChannelReader {
// though there could be more data ready to be read from the OS.
virtual bool DidEmptyInputBuffers() = 0;
- // Handles the first message sent over the pipe which contains setup info.
- virtual void HandleHelloMessage(const Message& msg) = 0;
+ // Handles internal messages, like the hello message sent on channel startup.
+ virtual void HandleInternalMessage(const Message& msg) = 0;
private:
// Takes the given data received from the IPC channel and dispatches any